#

##

##

    	passive voting

    	summary

    	questions

    		[ ] who chooses transaction order per block?

    			could be rotational based on order in which
    			accounts were added to the stamina database.

    				for example:
    					account 1 [1000 staked]
    					account 3 [1000 staked]
    					account 4
    					account 5
    					account 2

    				operation:
    					stake 1000
    					unstake 1000

    					unless stake goes to 0,
    					order in stamina order
    					remains the same.

    				conditionals:
    					if account is non-responsive:
    						accounts can vote to skip account in the order

    						like after 5 seconds of non-reponsiveness,
    						from the stamina leader, the tool could
    						be programmed to propose going to the next tool in the order.

    							{
    								"proposal": {
    									"name": "skip stamina leader",
    									"fields": {
    										"stamina leader": 4,

    										"squash": 245,
    										"block": 941
    									},
    								},
    								"signature":
    							}